@@ -93,6 +93,7 @@ pub(crate) type ChainReorgArgs = (
 pub(crate) enum Message {
     BlockTemplate(Request<BlockTemplateArgs, BlockTemplateResult>),
     SubmitLocalTx(Request<TransactionView, SubmitTxResult>),
+    RemoveLocalTx(Request<Byte32, bool>),
     SubmitRemoteTx(Request<(TransactionView, Cycle, PeerIndex), ()>),
     NotifyTxs(Notify<Vec<TransactionView>>),
     FreshProposalsFilter(Request<Vec<ProposalShortId>, Vec<ProposalShortId>>),
@@ -248,6 +249,21 @@ impl TxPoolController {
             .map_err(Into::into)
     }
 
+    /// Remove tx from tx-pool
+    pub fn remove_local_tx(&self, tx_hash: Byte32) -> Result<bool, AnyError> {
+        let (responder, response) = oneshot::channel();
+        let request = Request::call(tx_hash, responder);
+        self.sender
+            .try_send(Message::RemoveLocalTx(request))
+            .map_err(|e| {
+                let (_m, e) = handle_try_send_error(e);
+                e
+            })?;
+        block_in_place(|| response.recv())
+            .map_err(handle_recv_error)
+            .map_err(Into::into)
+    }
+
     /// Submit remote tx with declared cycles and origin to tx-pool
     pub async fn submit_remote_tx(
         &self,
@@ -770,6 +786,15 @@ async fn process(mut service: TxPoolService, message: Message) {
                 error!("responder send submit_tx result failed {:?}", e);
             };
         }
+        Message::RemoveLocalTx(Request {
+            responder,
+            arguments: tx_hash,
+        }) => {
+            let result = service.remove_tx(tx_hash).await;
+            if let Err(e) = responder.send(result) {
+                error!("responder send remove_tx result failed {:?}", e);
+            };
+        }
         Message::SubmitRemoteTx(Request {
             responder,
             arguments: (tx, declared_cycles, peer),
